@@ -26,21 +26,21 @@ extern void xmlCheckVersion(int version);
  *
  * the version string like "1.2.3"
  */
-#define LIBXML_DOTTED_VERSION "2.4.3"
+#define LIBXML_DOTTED_VERSION "2.4.4"
 
 /**
  * LIBXML_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXML_VERSION 20403
+#define LIBXML_VERSION 20404
 
 /**
  * LIBXML_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXML_VERSION_STRING "20403"
+#define LIBXML_VERSION_STRING "20404"
 
 /**
  * LIBXML_TEST_VERSION:
@@ -48,15 +48,22 @@ extern void xmlCheckVersion(int version);
  * Macro to check that the libxml version in use is compatible with
  * the version the software has been compiled against
  */
-#define LIBXML_TEST_VERSION xmlCheckVersion(20403);
+#define LIBXML_TEST_VERSION xmlCheckVersion(20404);
 
+#if 0
 /**
  * WITH_TRIO:
  *
- * Whether the trio support need to be configured in
+ * defined if the trio support need to be configured in
  */
-#if 0
 #define WITH_TRIO
+#else
+/**
+ * WITHOUT_TRIO:
+ *
+ * defined if the trio support should not be configured in
+ */
+#define WITHOUT_TRIO
 #endif
 
 /**
