@@ -8,10 +8,6 @@
 
 #include "libxml.h"
 
-#ifdef WIN32
-#undef LIBXML_DLL_IMPORT
-#endif
-
 #include <string.h>
 #include <stdarg.h>
 
